@@ -633,8 +633,10 @@ void getIGPUProperties(AppDelegate *appDelegate, NSMutableDictionary *configDict
 	NSMutableDictionary *devicesPropertiesDictionary = ([appDelegate isBootloaderOpenCore] ? [OpenCore getDevicePropertiesDictionaryWith:configDictionary typeName:@"Add"] : [Clover getDevicesPropertiesDictionaryWith:configDictionary]);
 	NSMutableDictionary *pciDeviceDictionary;
 	
-	if (![appDelegate tryGetGPUDeviceDictionary:&pciDeviceDictionary])
-		return;
+	//if (![appDelegate tryGetGPUDeviceDictionary:&pciDeviceDictionary])
+	//	return;
+    
+    [appDelegate tryGetGPUDeviceDictionary:&pciDeviceDictionary];
 	
 	NSString *deviceName = [pciDeviceDictionary objectForKey:@"DeviceName"];
 	NSString *className = [pciDeviceDictionary objectForKey:@"ClassName"];
